@@ -379,6 +379,10 @@ matchit2optimal <- function(treat, formula, data, distance, discarded,
 
   for (e in levels(ex)[cc]) {
     if (nlevels(ex) > 1) {
+      if (verbose) {
+        cat(sprintf("Matching subgroup %s/%s: %s...\n",
+                    match(e, levels(ex)[cc]), length(cc), e))
+      }
       mo_ <- mo[ex[treat_==1] == e, ex[treat_==0] == e]
     }
     else mo_ <- mo
